@@ -30,12 +30,17 @@ def mean(key_mapper=lambda i: i, reduce=False):
 
             def on_completed():
                 if reduce is True:
-                    observer.on_next(s/c)
+                    if c == 0:
+                        observer.on_next(None)
+                    else:
+                        observer.on_next(s/c)
+                observer.on_completed()
 
             return source.subscribe(
                 on_next=on_next,
                 on_completed=on_completed,
-                on_error=observer.on_error
+                on_error=observer.on_error,
+                scheduler=scheduler,
             )
         return rx.create(on_subscribe)
     return _mean
